import os


# WX config
WX_API_KEY = "f9d9b5267c097ce0c06b9ee39ee35c80"
WX_LOCATION = "chennai"
WX_METRIC_TEMP = "celsius"
WX_METRIC_WIND = "miles_hour"


# TIDY DOWNLOADS CONFIG
TIDY_ROOT = None


# SEARCH ENGINE
google_url = "http://google.com/search?q="
wiki_url = "http://wikipedia.org/wiki/"
youtube_url = "https:/youtube.com/results?search_query="
